@@ -19,31 +19,33 @@ package org.apache.maven.reporting;
  * under the License.
  */
 
-import org.apache.commons.validator.EmailValidator;
-import org.apache.commons.validator.UrlValidator;
-
 import org.apache.maven.doxia.sink.Sink;
+import org.apache.maven.doxia.sink.impl.SinkEventAttributeSet;
 import org.apache.maven.doxia.util.HtmlTools;
 
-import org.codehaus.plexus.util.StringUtils;
+import org.apache.maven.shared.utils.StringUtils;
 
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Map;
 import java.util.Properties;
 
 /**
- * An abstract class to manage report generation.
+ * <p>An abstract class to manage report generation, with many helper methods to ease the job: you just need to
+ * implement getTitle() and renderBody().</p>
+ *
+ * <p><strong>TODO</strong> Later it may be appropriate to create something like a VelocityMavenReportRenderer
+ * that could take a velocity template and pipe that through Doxia rather than coding them
+ * up like this.</p>
  *
  * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
  * @author <a href="evenisse@apache.org">Emmanuel Venisse</a>
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: AbstractMavenReportRenderer.java 942606 2010-05-09 20:17:20Z hboutemy $
  * @since 2.0
- * @TODO Later it may be appropriate to create something like a VelocityMavenReportRenderer
- * that could take a velocity template and pipe that through Doxia rather than coding them
- * up like this.
+ * @see #getTitle()
+ * @see #renderBody()
  */
 public abstract class AbstractMavenReportRenderer
     implements MavenReportRenderer
@@ -65,6 +67,7 @@ public abstract class AbstractMavenReportRenderer
     }
 
     /** {@inheritDoc} */
+    @Override
     public void render()
     {
         sink.head();
@@ -178,7 +181,7 @@ public abstract class AbstractMavenReportRenderer
      * @see Sink#section3_()
      * @see Sink#section4_()
      * @see Sink#section5_()
-     * @IllegalStateException if too many closing sections.
+     * @throws IllegalStateException if too many closing sections.
      */
     protected void endSection()
     {
@@ -290,7 +293,7 @@ public abstract class AbstractMavenReportRenderer
      * <p>If <code>asHtml</code> is true, add the text as Html</p>
      *
      * @param text the text to put in this cell, could be null.
-     * @param asHtml <tt>true</tt> to add the text as Html, <tt>false</tt> otherwise.
+     * @param asHtml {@code true} to add the text as Html, {@code false} otherwise.
      * @see #linkPatternedText(String)
      * @see Sink#tableCell()
      * @see Sink#tableCell_()
@@ -338,7 +341,6 @@ public abstract class AbstractMavenReportRenderer
 
     /**
      * Convenience method to wrap a table header row start in the current sink.
-     * <p>The texts in the <code>content</code> could be link patterned texts defined by <code>{text, url}</code></p>
      *
      * @param content an array of text to put in the cells in this row header, could be null.
      * @see #tableHeaderCell(String)
@@ -445,7 +447,7 @@ public abstract class AbstractMavenReportRenderer
      */
     protected void verbatimText( String text )
     {
-        sink.verbatim( true );
+        sink.verbatim( SinkEventAttributeSet.BOXED );
 
         text( text );
 
@@ -470,7 +472,7 @@ public abstract class AbstractMavenReportRenderer
         }
         else
         {
-            sink.verbatim( true );
+            sink.verbatim( SinkEventAttributeSet.BOXED );
 
             link( href, text );
 
@@ -507,7 +509,7 @@ public abstract class AbstractMavenReportRenderer
         }
         else
         {
-            List segments = applyPattern( text );
+            List<String> segments = applyPattern( text );
 
             if ( segments == null )
             {
@@ -515,10 +517,10 @@ public abstract class AbstractMavenReportRenderer
             }
             else
             {
-                for ( Iterator it = segments.iterator(); it.hasNext(); )
+                for ( Iterator<String> it = segments.iterator(); it.hasNext(); )
                 {
-                    String name = (String) it.next();
-                    String href = (String) it.next();
+                    String name = it.next();
+                    String href = it.next();
 
                     if ( href == null )
                     {
@@ -526,14 +528,7 @@ public abstract class AbstractMavenReportRenderer
                     }
                     else
                     {
-                        if ( getValidHref( href ) != null )
-                        {
-                            link( getValidHref( href ), name );
-                        }
-                        else
-                        {
-                            text( href );
-                        }
+                       link( href, name );
                     }
                 }
             }
@@ -562,10 +557,7 @@ public abstract class AbstractMavenReportRenderer
             return text;
         }
 
-        StringBuffer sb = new StringBuffer();
-        sb.append( "{" ).append( text ).append( ", " ).append( href ).append( "}" );
-
-        return sb.toString();
+        return '{' + text + ", " + href + '}';
     }
 
     /**
@@ -576,21 +568,21 @@ public abstract class AbstractMavenReportRenderer
      */
     protected static String propertiesToString( Properties props )
     {
-        StringBuffer sb = new StringBuffer();
-
         if ( props == null || props.isEmpty() )
         {
-            return sb.toString();
+            return "";
         }
 
-        for ( Iterator i = props.keySet().iterator(); i.hasNext(); )
+        StringBuilder sb = new StringBuilder();
+
+        for ( Map.Entry<?, ?> entry : props.entrySet() )
         {
-            String key = (String) i.next();
-            sb.append( key ).append( "=" ).append( props.get( key ) );
-            if ( i.hasNext() )
+            if ( sb.length() > 0 )
             {
                 sb.append( ", " );
             }
+
+            sb.append( entry.getKey() ).append( "=" ).append( entry.getValue() );
         }
 
         return sb.toString();
@@ -600,71 +592,6 @@ public abstract class AbstractMavenReportRenderer
     // Private methods
     // ----------------------------------------------------------------------
 
-    /**
-     * Return a valid href.
-     * <p>A valid href could start by <code>mailto:</code>.</p>
-     * <p>For a relative path, the href should start by <code>./</code> to be valid.</p>
-     *
-     * @param href an href, could be null.
-     * @return a valid href or <code>null</code> if the href is null or not valid.
-     */
-    private static String getValidHref( String href )
-    {
-        if ( StringUtils.isEmpty( href ) )
-        {
-            return null;
-        }
-
-        href = href.trim();
-
-        String[] schemes = {"http", "https"};
-        UrlValidator urlValidator = new UrlValidator( schemes );
-
-        if ( ( EmailValidator.getInstance().isValid( href ) )
-            || ( ( href.indexOf( "?" ) != -1 )
-                 && ( EmailValidator.getInstance().isValid( href.substring( 0, href.indexOf( "?" ) ) ) ) ) )
-        {
-            return "mailto:" + href;
-        }
-        else if ( href.toLowerCase().startsWith( "mailto:" ) )
-        {
-            return href;
-        }
-        else if ( urlValidator.isValid( href ) )
-        {
-            return href;
-        }
-        else
-        {
-            String hrefTmp;
-            if ( !href.endsWith( "/" ) )
-            {
-                hrefTmp = href + "/index.html";
-            }
-            else
-            {
-                hrefTmp = href + "index.html";
-            }
-
-            if ( urlValidator.isValid( hrefTmp ) )
-            {
-                return href;
-            }
-
-            if ( href.startsWith( "./" ) )
-            {
-                if ( href.length() > 2 )
-                {
-                    return href.substring( 2, href.length() );
-                }
-
-                return ".";
-            }
-
-            return null;
-        }
-    }
-
     /**
      * The method parses a text and applies the given pattern <code>{text, url}</code> to create
      * a list of text/href.
@@ -672,7 +599,7 @@ public abstract class AbstractMavenReportRenderer
      * @param text a text with or without the pattern <code>{text, url}</code>
      * @return a map of text/href
      */
-    private static List applyPattern( String text )
+    private static List<String> applyPattern( String text )
     {
         if ( StringUtils.isEmpty( text ) )
         {
@@ -681,14 +608,14 @@ public abstract class AbstractMavenReportRenderer
 
         // Map defined by key/value name/href
         // If href == null, it means
-        List segments = new ArrayList();
+        List<String> segments = new ArrayList<>();
 
         // TODO Special case http://jira.codehaus.org/browse/MEV-40
         if ( text.indexOf( "${" ) != -1 )
         {
             int lastComma = text.lastIndexOf( "," );
             int lastSemi = text.lastIndexOf( "}" );
-            if ( lastComma != -1 && lastSemi != -1 )
+            if ( lastComma != -1 && lastSemi != -1 && lastComma < lastSemi )
             {
                 segments.add( text.substring( lastComma + 1, lastSemi ).trim() );
                 segments.add( null );
@@ -734,7 +661,7 @@ public abstract class AbstractMavenReportRenderer
                         {
                             if ( braceStack == 0 )
                             {
-                                if ( i != 0 ) // handle { at first character
+                                if ( i != lastOffset ) // handle { at first character
                                 {
                                     segments.add( text.substring( lastOffset, i ) );
                                     segments.add( null );
@@ -776,9 +703,9 @@ public abstract class AbstractMavenReportRenderer
             }
         }
 
-        if ( !StringUtils.isEmpty( text.substring( lastOffset, text.length() ) ) )
+        if ( !StringUtils.isEmpty( text.substring( lastOffset ) ) )
         {
-            segments.add( text.substring( lastOffset, text.length() ) );
+            segments.add( text.substring( lastOffset ) );
             segments.add( null );
         }
 
@@ -800,7 +727,7 @@ public abstract class AbstractMavenReportRenderer
     // Abstract methods
     // ----------------------------------------------------------------------
 
-    /** {@inheritDoc} */
+    @Override
     public abstract String getTitle();
 
     /**
